==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-th-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: th\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: "โทร"

, "Calls"
: "โทร"

, "Line"
: "สาย"

, "Caller Id"
: "หมายเลขผู้โทร"

, "Start"
: "เริ่มต้น"

, "Connected"
: "ติดต่อแล้ว"

, "Disconnected"
: "ติดต่อไม่ได้"

, "Duration"
: "ระยะเวลา"

, "Ringing"
: "กำลังรอสาย"

, "Direction"
: "ทิศทาง"

, "Source"
: "แหล่ง"

, "Destination"
: "ปลายทาง"

, "Phone"
: "โทรศัพท์"

, "Phones"
: "โทรศัพท์"

, "Settings"
: "ค่าติดตั้ง"

, "Lines"
: "สาย"

, "Description"
: "การอธิบาย"

, "Number"
: "หมายเลข"

, "Cancel"
: "ยกเลิก"

, "Dial"
: "ติดต่อ"

, "Error"
: "ผิดพลาด"

, "Not possible to dial."
: "ไม่สามารถติดต่อได้"

, "Edit phone settings"
: "จัดการการตั้งค่าโทรศัพท์"

, "Dial number"
: "ติดต่อหมายเลข"

, "Initiate a new outgoing call"
: "เริ่มการโทรออกใหม่"

, "No phone selected"
: "ไม่ได้เลือกโทรศัพท์ใด ๆ "

, "Please select the desired phone in the tree!"
: "กรุณาเลือกโทรศัพท์ที่ต้องการจากแผนผังต้นไม้"

, "Call contact"
: "โทรติดต่อ"

, "Work"
: "ที่ทำงาน"

, "Home"
: "ที่บ้าน"

, "Cell"
: "มือถือ"

, "Cell private"
: "โทรศัพท์เคลื่อนที่ ส่วนตัว"

, "Incoming call"
: "เบอร์โทรเข้า"

, "Outgoing call"
: "เบอร์โทรออก"

, "unknown number"
: "หมายเลขที่ไม่รู้จัก"

, "local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: ""

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: "เบอร์ที่ติดต่อในสัปดาห์นี้"

, "Incoming and outgoing calls of this week"
: "เบอร์โทรเข้า/ออกของสัปดาห์นี้"

, "Calls last week"
: "เบอร์ที่ติดต่อสัปดาห์ที่แล้ว"

, "Incoming and outgoing calls of last week"
: "เบอร์โทรเข้า/ออกของสัปดาห์ที่แล้ว"

, "Calls this month"
: "เบอร์ที่ติดต่อในเดือนนี้"

, "Incoming and outgoing calls of this month"
: "เบอร์โทรเข้า/ออกของเดือนนี้"

, "Calls last month"
: "เบอร์ที่ติดต่อเดือนที่แล้ว"

, "Incoming and outgoing calls of last month"
: "เบอร์โทรเข้า/ออกของเดือนที่แล้ว"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.03.4.tar.bz2: Phone/js/Phone-lang-th-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: "เบอร์โทรเข้า"

, "Outgoing call"
: "เบอร์โทรออก"

, "unknown number"
: "หมายเลขที่ไม่รู้จัก"

, "Phone"
: "โทรศัพท์"

, "Line"
: "สาย"

, "Number"
: "หมายเลข"

, "Cancel"
: "ยกเลิก"

, "Dial"
: "ติดต่อ"

, "Error"
: "ผิดพลาด"

, "Not possible to dial."
: "ไม่สามารถติดต่อได้"

, "Call contact"
: "โทรติดต่อ"

, "Work"
: "ที่ทำงาน"

, "Home"
: "ที่บ้าน"

, "Cell"
: "มือถือ"

, "Cell private"
: "โทรศัพท์เคลื่อนที่ ส่วนตัว"

, "Edit phone settings"
: "จัดการการตั้งค่าโทรศัพท์"

, "Dial number"
: "ติดต่อหมายเลข"

, "Initiate a new outgoing call"
: "เริ่มการโทรออกใหม่"

, "Phones"
: "โทรศัพท์"

, "No phone selected"
: "ไม่ได้เลือกโทรศัพท์ใด ๆ "

, "Please select the desired phone in the tree!"
: "กรุณาเลือกโทรศัพท์ที่ต้องการจากแผนผังต้นไม้"

, "Calls this week"
: "เบอร์ที่ติดต่อในสัปดาห์นี้"

, "Calls last week"
: "เบอร์ที่ติดต่อสัปดาห์ที่แล้ว"

, "Calls this month"
: "เบอร์ที่ติดต่อในเดือนนี้"

, "Calls last month"
: "เบอร์ที่ติดต่อเดือนที่แล้ว"

, "Incoming and outgoing calls of this week"
: "เบอร์โทรเข้า/ออกของสัปดาห์นี้"

, "Incoming and outgoing calls of last week"
: "เบอร์โทรเข้า/ออกของสัปดาห์ที่แล้ว"

, "Incoming and outgoing calls of this month"
: "เบอร์โทรเข้า/ออกของเดือนนี้"

, "Incoming and outgoing calls of last month"
: "เบอร์โทรเข้า/ออกของเดือนที่แล้ว"

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: ""

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: "โทร"

, "Calls"
: "โทร"

, "Caller Id"
: "หมายเลขผู้โทร"

, "Start"
: "เริ่มต้น"

, "Connected"
: "ติดต่อแล้ว"

, "Disconnected"
: "ติดต่อไม่ได้"

, "Duration"
: "ระยะเวลา"

, "Ringing"
: "กำลังรอสาย"

, "Direction"
: "ทิศทาง"

, "Source"
: "แหล่ง"

, "Destination"
: "ปลายทาง"

, "resolved destination"
: ""

, "Settings"
: "ค่าติดตั้ง"

, "Lines"
: "สาย"

, "Description"
: "การอธิบาย"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
